Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(6562)

Unified Diff: chrome/browser/sync/about_sync_util.cc

Issue 1269773002: Cleanup VersionInfo after componentization. (Closed) Base URL: https://chromium.googlesource.com/chromium/src.git@master
Patch Set: Rebase Created 5 years, 4 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/browser/sxs_linux.cc ('k') | chrome/browser/sync/glue/chrome_report_unrecoverable_error.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/browser/sync/about_sync_util.cc
diff --git a/chrome/browser/sync/about_sync_util.cc b/chrome/browser/sync/about_sync_util.cc
index e10fb3c6942c563dcdb4922cd90d921ad51021ef..04a2a3045f91252cd03f367be97094e39be92d46 100644
--- a/chrome/browser/sync/about_sync_util.cc
+++ b/chrome/browser/sync/about_sync_util.cc
@@ -10,8 +10,9 @@
#include "base/strings/stringprintf.h"
#include "base/values.h"
#include "chrome/browser/sync/profile_sync_service.h"
-#include "chrome/common/chrome_version_info.h"
+#include "chrome/common/channel_info.h"
#include "components/signin/core/browser/signin_manager.h"
+#include "components/version_info/version_info.h"
#include "sync/api/time.h"
#include "sync/internal_api/public/util/sync_string_conversions.h"
#include "sync/protocol/proto_enum_conversions.h"
@@ -142,23 +143,20 @@ void IntSyncStat::SetValue(int value) {
std::string GetVersionString() {
// Build a version string that matches MakeUserAgentForSyncApi with the
// addition of channel info and proper OS names.
- chrome::VersionInfo chrome_version;
- // GetVersionStringModifier returns empty string for stable channel or
+ // chrome::GetChannelString() returns empty string for stable channel or
// unofficial builds, the channel string otherwise. We want to have "-devel"
// for unofficial builds only.
- std::string version_modifier =
- chrome::VersionInfo::GetVersionStringModifier();
+ std::string version_modifier = chrome::GetChannelString();
if (version_modifier.empty()) {
- if (chrome::VersionInfo::GetChannel() !=
- version_info::Channel::STABLE) {
+ if (chrome::GetChannel() != version_info::Channel::STABLE) {
version_modifier = "-devel";
}
} else {
version_modifier = " " + version_modifier;
}
- return chrome_version.Name() + " " + chrome_version.OSType() + " " +
- chrome_version.Version() + " (" + chrome_version.LastChange() + ")" +
- version_modifier;
+ return version_info::GetProductName() + " " + version_info::GetOSType() +
+ " " + version_info::GetVersionNumber() + " (" +
+ version_info::GetLastChange() + ")" + version_modifier;
}
std::string GetTimeStr(base::Time time, const std::string& default_msg) {
« no previous file with comments | « chrome/browser/sxs_linux.cc ('k') | chrome/browser/sync/glue/chrome_report_unrecoverable_error.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698